package com.dzeio.openhealth.extensions

import android.app.Activity
import android.content.Intent
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.dzeio.openhealth.data.weight.Weight

/**
 * Extension Schema
 *
 * Version: 1.0.0
 */
abstract class Extension {

    data class ImportState<T>(
        val state: States = States.WIP,
        val list: List<T> = ArrayList()
    )

    enum class States {
        WIP,
        DONE,
        CANCELLED
    }

    enum class Data {
        /**
         * Special case to handle basic errors from other activities
         */
        NOTHING,
        WEIGHT,
        STEPS

        /**
         * STEP_COUNT_CUMULATIVE
         * ACTIVITY_SEGMENT
         * SLEEP_SEGMENT
         * CALORIES_EXPENDED
         * BASAL_METABOLIC_RATE
         * POWER_SAMPLE
         * HEART_RATE_BPM
         * LOCATION_SAMPLE
         */
    }

    /**
     * the Source ID
     *
     * DO NOT CHANGE IT AFTER THE EXTENSION IS IN PRODUCTION
     */
    abstract val id: String

    /**
     * The Extension Display Name
     */
    abstract val name: String

    /**
     * Initialize hte Extension
     *
     * It is run Before any functions is launched and after events handlers are set
     */
    abstract fun init(activity: Activity): Array<Data>

    /**
     * A status shown on the extension list page
     */
    open fun getStatus(): String {
        return "No Status set..."
    }

    /**
     * Function that will check
     */
    abstract fun isAvailable(): Boolean

    /**
     * idk
     */
    abstract fun isConnected(): Boolean

    open fun connect(): LiveData<States> {
        return MutableLiveData(States.DONE)
    }

    open fun importWeight(): LiveData<ImportState<Weight>> {
        return MutableLiveData(ImportState(States.DONE))
    }

    /**
     * function run when outgoing sync is enabled and new value is added
     * or manual export is launched
     */
    open fun exportWeight(weight: Weight): LiveData<States> {
        return MutableLiveData(States.DONE)
    }

    /**
     * Activity Events
     */

    /**
     * Same as Activity/Fragment onRequestPermissionResult
     *
     * But it will only be launched if grantResults[0] == PackageManager.PERMISSION_GRANTED
     */
    open fun onRequestPermissionResult(requestCode: Int, permission: Array<String>, grantResult: IntArray) {}

    /**
     * Same as Activity/Fragment onActivityResult
     */
    open fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {}
}