package com.dzeio.openhealth.ui.home

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.viewModelScope
import com.dzeio.openhealth.core.BaseViewModel
import com.dzeio.openhealth.data.water.Water
import com.dzeio.openhealth.data.water.WaterRepository
import com.dzeio.openhealth.data.weight.Weight
import com.dzeio.openhealth.data.weight.WeightRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.collectLatest
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class HomeViewModel @Inject internal constructor(
    private val weightRepository: WeightRepository,
    private val waterRepository: WaterRepository
) : BaseViewModel() {

    init {
        viewModelScope.launch {
            waterRepository.todayWater().collectLatest {
                _water.value = it
            }
        }
    }

    /**
     * @deprecated
     */
    fun fetchWeights() = weightRepository.getWeights()


    /**
     * @deprecated
     */
    fun lastWeight() = weightRepository.lastWeight()

    fun fetchWeight(id: Long) = weightRepository.getWeight(id)

    suspend fun deleteWeight(weight: Weight) = weightRepository.deleteWeight(weight)

    suspend fun addWeight(weight: Weight) = weightRepository.addWeight(weight)

    suspend fun fetchTodayWater() = waterRepository.todayWater()

    private val _water = MutableLiveData<Water?>(null)
    val water: LiveData<Water?> = _water


    fun updateWater(water: Water) {
        viewModelScope.launch {
            waterRepository.addWater(water)
        }
    }

    fun deleteWater(item: Water) {
        viewModelScope.launch {
            waterRepository.deleteWater(item)
            _water.postValue(null)
        }
    }
}