package com.dzeio.openhealth.utils

import com.github.mikephil.charting.charts.BarChart
import com.github.mikephil.charting.charts.BarLineChartBase
import com.github.mikephil.charting.charts.LineChart
import com.github.mikephil.charting.components.AxisBase
import com.github.mikephil.charting.components.Description
import com.github.mikephil.charting.components.XAxis
import com.github.mikephil.charting.data.BarLineScatterCandleBubbleData
import com.github.mikephil.charting.data.Entry
import com.github.mikephil.charting.formatter.ValueFormatter
import com.github.mikephil.charting.interfaces.datasets.IBarLineScatterCandleBubbleDataSet
import java.text.SimpleDateFormat
import java.util.*

object GraphUtils {

    fun lineChartSetup(chart: LineChart, mainColor: Int, textColor: Int) {
        barLineChartSetup(chart, mainColor, textColor)
    }

    fun barChartSetup(chart: BarChart, mainColor: Int, textColor: Int) {
        barLineChartSetup(chart, mainColor, textColor)
    }

    private fun <T : BarLineScatterCandleBubbleData<out IBarLineScatterCandleBubbleDataSet<out Entry>>?> barLineChartSetup(
        chart: BarLineChartBase<T>,
        mainColor: Int,
        textColor: Int
    ) {

        chart.apply {

            // Setup
            legend.isEnabled = false
            description = Description().apply { isEnabled = false }

            xAxis.apply {
                valueFormatter = object : ValueFormatter() {
                    override fun getAxisLabel(value: Float, axis: AxisBase?): String {
                        return SimpleDateFormat(
                            "yyyy-MM-dd",
                            Locale.getDefault()
                        ).format(Date(value.toLong()))
                        //return super.getAxisLabel(value, axis)
                    }
                }
                position = XAxis.XAxisPosition.BOTTOM
                setDrawGridLines(false)
                setLabelCount(3, true)
                this.textColor = textColor
                //setDrawGridLines(false)
                //setDrawZeroLine(false)
                setDrawAxisLine(false)
                disableGridDashedLine()
                invalidateOutline()
            }

            axisLeft.apply {
                axisLineColor = mainColor
                this.textColor = textColor
//                setDrawZeroLine(false)
                setLabelCount(0, true)
                setDrawGridLines(false)
            }
            axisRight.apply {
                this.textColor = textColor
            }
            setNoDataTextColor(textColor)


            isAutoScaleMinMaxEnabled = true
            legend.isEnabled = false
            isDragEnabled = true
            isScaleYEnabled = false
            description = Description().apply { isEnabled = false }
            isScaleXEnabled = true
            setPinchZoom(false)
            setDrawGridBackground(false)
            setDrawBorders(false)
        }
    }
}